@@ -6,6 +6,12 @@ sub _hide_this {
   'here there be dragons';
 }
 
+=head2 show_this
+
+Contains chickens
+
+=cut
+
 sub show_this {
   'here there be chickens';
 }
